==> infra-5.1.0-sources.jar: com/liveperson/infra/network/http/requests/CSDSRequest.java <==
package com.liveperson.infra.network.http.requests;

import android.text.TextUtils;

import com.liveperson.infra.Command;
import com.liveperson.infra.ICallback;
import com.liveperson.infra.log.LPMobileLog;
import com.liveperson.infra.network.http.HttpHandler;
import com.liveperson.infra.network.http.request.HttpGetRequest;

import org.json.JSONArray;
import org.json.JSONException;
import org.json.JSONObject;

import java.util.HashMap;
import java.util.List;

/**
 * Created by Ilya Gazman on 11/3/2015.
 * <p/>
 * A request to fetch CSDS
 */
public class CSDSRequest implements Command {

    private static final String TAG = CSDSRequest.class.getSimpleName();
    private static final String CSDS_URL = "https://%1$s/csdr/account/%2$s/service/baseURI.json?version=1.0";
    private static final int CSDS_REQUEST_TIMEOUT = 30000;
    private ICallback mCallback;
    private String mBrandId;
    private String mDomain;
    private List<String> mCertificates;

    public CSDSRequest(String domain, String brandId, List<String> certificates, ICallback callback) {
        mCallback = callback;
        mBrandId = brandId;
        mCertificates = certificates;
        mDomain = domain;
    }


    /**
     * Execute CSDS request
     */
    @Override
    public void execute() {

        final String cSDSRequestUrl = String.format(CSDS_URL, mDomain, mBrandId);
        HttpGetRequest httpGetRequest = new HttpGetRequest(cSDSRequestUrl);
        httpGetRequest.setTimeout(CSDS_REQUEST_TIMEOUT);
        httpGetRequest.setCertificatePinningKeys(mCertificates);
        httpGetRequest.setCallback(new ICallback<String, Exception>() {
            @Override
            public void onSuccess(String csdsString) {
                if (!TextUtils.isEmpty(csdsString)) {
                    try {
                        JSONObject csdsJson = new JSONObject(csdsString);
                        JSONArray csdsResponse = csdsJson.optJSONArray("baseURIs");
                        if (csdsResponse.length() == 0) {
                            mCallback.onError(new Exception("CSDS response: Brand not found. url = " + cSDSRequestUrl));
                        } else {
                            HashMap<String, String> mCSDSUrls = parseCSDSResponse(csdsResponse);
                            mCallback.onSuccess(mCSDSUrls);
                        }
                    } catch (JSONException je) {

                    }
                } else {
                    mCallback.onError(new Exception("CSDS response: csdsString is empty"));
                }
            }

            @Override
            public void onError(Exception exception) {
                LPMobileLog.w(TAG, "CSDS failed! url = " + cSDSRequestUrl + ". error: ", exception);
                mCallback.onError(exception);
            }
        });
        HttpHandler.execute(httpGetRequest);
    }

    /**
     * Parsing server data
     *
     * @param cSDSResponse
     * @return
     */
    private HashMap<String, String> parseCSDSResponse(JSONArray cSDSResponse) throws JSONException {
        HashMap<String, String> mCSDSUrls = new HashMap<>(cSDSResponse.length());
        for (int i = 0; i < cSDSResponse.length(); i++) {
            JSONObject service = cSDSResponse.optJSONObject(i);
            String serviceName = service.optString("service");
            String baseURIName = service.optString("baseURI");
            LPMobileLog.d(TAG, "serviceName: " + serviceName + " : " + baseURIName);
            mCSDSUrls.put(serviceName, baseURIName);
        }

        return mCSDSUrls;
    }
}

==> infra-5.18.0-sources.jar: com/liveperson/infra/network/http/requests/CSDSRequest.java <==
package com.liveperson.infra.network.http.requests;

import com.liveperson.infra.Command;
import com.liveperson.infra.ICallback;
import com.liveperson.infra.log.LPLog;
import com.liveperson.infra.network.http.HttpHandler;
import com.liveperson.infra.network.http.request.HttpGetRequest;
import com.liveperson.infra.utils.StringUtils;

import org.json.JSONArray;
import org.json.JSONException;
import org.json.JSONObject;

import java.util.HashMap;
import java.util.List;

/**
 * Created by Ilya Gazman on 11/3/2015.
 * <p/>
 * A request to fetch CSDS
 */
public class CSDSRequest implements Command {

    private static final String TAG = "CSDSRequest";
    private static final String CSDS_URL = "https://%1$s/csdr/account/%2$s/service/baseURI.json?version=1.0";
    private static final String CSDS_SERVICE_BASED_URL = "https://%1$s/csdr/account/%2$s/service/%3$s/baseURI.json?version=1.0";
    private static final int CSDS_REQUEST_TIMEOUT = 30000;
    private ICallback<HashMap<String, String>, Exception> mCallback;
    private String mBrandId;
    private String mDomain;
    private List<String> mCertificates;
    private String mServiceName;

    public CSDSRequest(String domain, String brandId, List<String> certificates, ICallback<HashMap<String, String>, Exception> callback) {
        this(domain, brandId, "", certificates,  callback);
    }

    public CSDSRequest(String domain, String brandId, String serviceName, List<String> certificates, ICallback<HashMap<String, String>, Exception> callback) {
        mCallback = callback;
        mBrandId = brandId;
        mCertificates = certificates;
        mDomain = domain;
        mServiceName = serviceName;
    }


    /**
     * Execute CSDS request
     */
    @Override
    public void execute() {

        final String cSDSRequestUrl = StringUtils.isEmpty(mServiceName) ?
                String.format(CSDS_URL, mDomain, mBrandId) :
                String.format(CSDS_SERVICE_BASED_URL, mDomain, mBrandId, mServiceName);
        HttpGetRequest httpGetRequest = new HttpGetRequest(cSDSRequestUrl);
        httpGetRequest.setTimeout(CSDS_REQUEST_TIMEOUT);
        httpGetRequest.setCertificatePinningKeys(mCertificates);
        httpGetRequest.setCallback(new ICallback<String, Exception>() {
            @Override
            public void onSuccess(String csdsString) {
                if (!StringUtils.isEmpty(csdsString)) {
                    try {
                        JSONObject csdsJson = new JSONObject(csdsString);

                        JSONArray csdsResponse = csdsJson.has("baseURIs") ?
                                csdsJson.optJSONArray("baseURIs") : new JSONArray().put(csdsJson);
                        if (csdsResponse.length() == 0) {
                            mCallback.onError(new Exception("CSDS response: Brand not found. url = " + cSDSRequestUrl));
                        } else {
                            HashMap<String, String> mCSDSUrls = parseCSDSResponse(csdsResponse);
                            mCallback.onSuccess(mCSDSUrls);
                        }
                    } catch (JSONException je) {
                        mCallback.onError(je);
                    }
                } else {
                    mCallback.onError(new Exception("CSDS response: csdsString is empty"));
                }
            }

            @Override
            public void onError(Exception exception) {
                LPLog.INSTANCE.w(TAG, "CSDS failed! url = " + cSDSRequestUrl + ". error: ", exception);
                mCallback.onError(exception);
            }
        });
        HttpHandler.execute(httpGetRequest);
    }

    /**
     * Parsing server data
     */
    private HashMap<String, String> parseCSDSResponse(JSONArray cSDSResponse) {
        HashMap<String, String> mCSDSUrls = new HashMap<>(cSDSResponse.length());
        for (int i = 0; i < cSDSResponse.length(); i++) {
            JSONObject service = cSDSResponse.optJSONObject(i);
            String serviceName = service.optString("service");
            String baseURIName = service.optString("baseURI");
            LPLog.INSTANCE.d(TAG, "serviceName: " + serviceName + " : " + baseURIName);
            mCSDSUrls.put(serviceName, baseURIName);
        }

        return mCSDSUrls;
    }
}
